#!/usr/bin/python
import os
import sys

if 'OPENSHIFT_PYTHON_DIR' in os.environ:
    virtenv = os.environ['OPENSHIFT_PYTHON_DIR'] + '/virtenv/'
    virtualenv = os.path.join(virtenv, 'bin/activate_this.py')
    try:
        execfile(virtualenv, dict(__file__=virtualenv))
    except IOError:
        pass
#
# IMPORTANT: Put any additional includes below this line.  If placed above this
# line, it's possible required libraries won't be in your searchable path
#

from whitenoise import WhiteNoise

BASE_WCS_DIR = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'wcs')
sys.path.append(BASE_WCS_DIR)
if os.path.exists(os.path.join(BASE_WCS_DIR, 'data/vendor/effective_tld_names.dat')):
    # remove that file to get full domaine name in cookies
    os.unlink(os.path.join(BASE_WCS_DIR, 'data/vendor/effective_tld_names.dat'))

from wcs import publisher
from wcs.qommon.http_request import HTTPRequest

class QWIP:
    # copy of quixote original QWIP code, adapted to use our own HTTPRequest
    # object and to process after jobs.
    request_class = HTTPRequest

    def __init__(self, publisher):
        self.publisher = publisher

    def __call__(self, env, start_response):
        """I am called for each request."""
        if 'REQUEST_URI' not in env:
            env['REQUEST_URI'] = env['SCRIPT_NAME'] + env['PATH_INFO']
        input = env['wsgi.input']
        request = self.request_class(input, env)
        response = self.publisher.process_request(request)
        status = "%03d %s" % (response.status_code, response.reason_phrase)
        headers = response.generate_headers()
        start_response(status, headers)
        result = list(response.generate_body_chunks())  # Iterable object.
        response.process_after_jobs()
        return result

publisher.WcsPublisher.APP_DIR = os.environ.get('OPENSHIFT_DATA_DIR', '/tmp/')
publisher.WcsPublisher.DATA_DIR = os.path.join(BASE_WCS_DIR, 'data')
pub = publisher.WcsPublisher.create_publisher(register_cron=False)

application = WhiteNoise(QWIP(pub))
application.add_files(os.path.join(BASE_WCS_DIR, 'wcs/qommon/static'), 'qo')

if __name__ == '__main__':
    from wsgiref.simple_server import make_server
    httpd = make_server('localhost', 8051, application)
    while True:
        # Wait for a single request, serve it and quit.
        httpd.handle_request()
